diff --git a/.travis.yml b/.travis.yml
index d25da47..306c1a4 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -12,8 +12,8 @@ before_script:
- 'if [[ $NPMVERSION == 5 ]]; then npm install -g npm@5; fi'
- npm -v
- npm install winston@2.3.0 --production
- - 'npm install https://github.com/ioBroker/ioBroker.js-controller/tarball/master --production'
- - npm install iobroker.web --prefix ./node_modules/iobroker.js-controller/ --production
+ - 'npm install https://github.com/yunkong2/yunkong2.js-controller/tarball/master --production'
+ - npm install yunkong2.web --prefix ./node_modules/yunkong2.js-controller/ --production
env:
- CXX=g++-4.8
addons:
diff --git a/Gruntfile.js b/Gruntfile.js
index 51ee865..4f5911e 100644
--- a/Gruntfile.js
+++ b/Gruntfile.js
@@ -89,7 +89,7 @@ module.exports = function (grunt) {
options: {
patterns: [
{
- match: /iobroker/gi,
+ match: /yunkong2/gi,
replacement: appName
},
{
diff --git a/OLD_CHANGELOG.md b/OLD_CHANGELOG.md
index 2a4c213..61f2056 100644
--- a/OLD_CHANGELOG.md
+++ b/OLD_CHANGELOG.md
@@ -70,7 +70,7 @@
* (bluefox) make red-number working again.
* (bluefox) extend dialog with atuoclose timeout
* (bluefox) add editWidgetNames
-* (bluefox) remove jqueryUI files to iobroker.web
+* (bluefox) remove jqueryUI files to yunkong2.web
### 0.7.4 (2015-10-27)
* (SmilingJack) add "jqui-navigation" with password
@@ -341,7 +341,7 @@
- (bluefox) fix installation process
### 0.2.11 (2015-03-11)
-- (bluefox) fix install for iobroker. Required newest ioBroke.js-controller
+- (bluefox) fix install for yunkong2. Required newest ioBroke.js-controller
### 0.2.10 (2015-03-09)
- (bluefox) fix install for node-red-vis
diff --git a/README.md b/README.md
index ccc9630..040acc9 100644
--- a/README.md
+++ b/README.md
@@ -1,20 +1,20 @@

-# iobroker.vis
+# yunkong2.vis
============
-[](https://www.npmjs.com/package/iobroker.vis)
-[](https://www.npmjs.com/package/iobroker.vis)
+[](https://www.npmjs.com/package/yunkong2.vis)
+[](https://www.npmjs.com/package/yunkong2.vis)
-[](https://nodei.co/npm/iobroker.vis/)
+[](https://nodei.co/npm/yunkong2.vis/)
-WEB visualisation for iobroker platform.
+WEB visualisation for yunkong2 platform.
## Installation & Documentation


-[Online Demos](https://iobroker.net:8080)
+[Online Demos](https://yunkong2.net:8080)
## Bindings of objects
Normally most of widgets have ObjectID attribute. And this attribute can be bound with some value of object ID.
@@ -41,7 +41,7 @@ Following operations are supported:
- hex2 - convert value to hexadecimal value. All letters are lower cased. If value less 16, so the leading zero will be added.
- HEX - same as hex, but upper cased.
- HEX2 - same as hex2, but upper cased.
-- date - format date according to given format. Format is the same as in [iobroker.javascript](https://github.com/iobroker/iobroker.javascript/blob/master/README.md#formatdate)
+- date - format date according to given format. Format is the same as in [yunkong2.javascript](https://github.com/yunkong2/yunkong2.javascript/blob/master/README.md#formatdate)
- min(N) - if value is less than N, take the N, elsewise value
- max(M) - if value is greater than M, take the M, elsewise value
- sqrt - square root
@@ -202,7 +202,7 @@ Notice that this settings is valid only for reconnection and not for the first c
* (bluefox) show error stack
* (bluefox) fix binding
* (Apollon77) fix testing
-* (bluefox) fix for iobroker.pro and external socket.io settings
+* (bluefox) fix for yunkong2.pro and external socket.io settings
* (bluefox) A user variable was added into bindings.
* (bluefox) Fixed widget tabs
diff --git a/admin/i18n/de/translations.json b/admin/i18n/de/translations.json
index 342d259..c6e1d17 100644
--- a/admin/i18n/de/translations.json
+++ b/admin/i18n/de/translations.json
@@ -2,6 +2,6 @@
"Check license": "Lizenz prüfen",
"License:": "License Key:",
"Service is offline. Please try later.": "Service ist momentan nicht erreichbar oder keine Internetverbindung vorhanden. Bitte fersuchen Sie später noch ein mal oder prüfen Sie die Internetverbindung.",
- "instruction": "Man braucht eine Lizenz um vis zu nutzen.
vis ist kostenlos für private Nutzung. Nur für kommerzielle Gebrauch muss man für eine Lizenz bezahlen.
Man kann eine Lizenz auf iobroker.net nach der Registrierung bekommen.",
+ "instruction": "Man braucht eine Lizenz um vis zu nutzen.
vis ist kostenlos für private Nutzung. Nur für kommerzielle Gebrauch muss man für eine Lizenz bezahlen.
Man kann eine Lizenz auf yunkong2.net nach der Registrierung bekommen.",
"vis adapter settings": "vis Adapter-Einstellungen"
}
\ No newline at end of file
diff --git a/admin/i18n/en/translations.json b/admin/i18n/en/translations.json
index 171b92d..f71564b 100644
--- a/admin/i18n/en/translations.json
+++ b/admin/i18n/en/translations.json
@@ -2,6 +2,6 @@
"Check license": "Check license",
"License:": "License key:",
"Service is offline. Please try later.": "Service is offline or no internet available. Please try later or check the internet connection.",
- "instruction": "To use vis, you must get the license key for it.
vis is free for private use, but for commercial use it has a price.
You can get the license on iobroker.net after short registration.",
+ "instruction": "To use vis, you must get the license key for it.
vis is free for private use, but for commercial use it has a price.
You can get the license on yunkong2.net after short registration.",
"vis adapter settings": "vis adapter settings"
}
\ No newline at end of file
diff --git a/admin/i18n/es/translations.json b/admin/i18n/es/translations.json
index 405b94f..39bcdb2 100644
--- a/admin/i18n/es/translations.json
+++ b/admin/i18n/es/translations.json
@@ -2,6 +2,6 @@
"Check license": "Verificar licencia",
"License:": "Clave de licencia:",
"Service is offline. Please try later.": "El servicio está fuera de línea o no hay internet disponible. Por favor intente más tarde o verifique la conexión a internet.",
- "instruction": "Para usar vis , debe obtener la clave de licencia correspondiente.
vis es gratuito para uso privado, pero para uso comercial tiene un precio.
Usted puede obtener la licencia en iobroker.net después de un breve registro.",
+ "instruction": "Para usar vis , debe obtener la clave de licencia correspondiente.
vis es gratuito para uso privado, pero para uso comercial tiene un precio.
Usted puede obtener la licencia en yunkong2.net después de un breve registro.",
"vis adapter settings": "vis configuración del adaptador"
}
\ No newline at end of file
diff --git a/admin/i18n/fr/translations.json b/admin/i18n/fr/translations.json
index 2bdfe23..384d28e 100644
--- a/admin/i18n/fr/translations.json
+++ b/admin/i18n/fr/translations.json
@@ -2,6 +2,6 @@
"Check license": "Vérifier la licence",
"License:": "Clé de licence:",
"Service is offline. Please try later.": "Le service est hors ligne ou pas disponible sur Internet. Veuillez réessayer plus tard ou vérifier la connexion Internet.",
- "instruction": "Pour utiliser vis , vous devez obtenir la clé de licence.
vis est libre pour un usage privé, mais pour un usage commercial, il a un prix.
Vous peut obtenir la licence sur iobroker.net après une brève inscription.",
+ "instruction": "Pour utiliser vis , vous devez obtenir la clé de licence.
vis est libre pour un usage privé, mais pour un usage commercial, il a un prix.
Vous peut obtenir la licence sur yunkong2.net après une brève inscription.",
"vis adapter settings": "paramètres de l'adaptateur vis"
}
\ No newline at end of file
diff --git a/admin/i18n/it/translations.json b/admin/i18n/it/translations.json
index 2f125b2..0bf89c3 100644
--- a/admin/i18n/it/translations.json
+++ b/admin/i18n/it/translations.json
@@ -2,6 +2,6 @@
"Check license": "Controlla la licenza",
"License:": "Chiave di licenza:",
"Service is offline. Please try later.": "Il servizio è offline o non disponibile su Internet. Si prega di provare più tardi o controllare la connessione internet.",
- "instruction": "Per utilizzare vis , devi ottenere il codice di licenza per esso.
vis è gratuito per uso privato, ma per uso commerciale ha un prezzo.
Tu può ottenere la licenza su iobroker.net dopo una breve registrazione.",
+ "instruction": "Per utilizzare vis , devi ottenere il codice di licenza per esso.
vis è gratuito per uso privato, ma per uso commerciale ha un prezzo.
Tu può ottenere la licenza su yunkong2.net dopo una breve registrazione.",
"vis adapter settings": "impostazioni della scheda vis"
}
\ No newline at end of file
diff --git a/admin/i18n/nl/translations.json b/admin/i18n/nl/translations.json
index e27e879..f481dde 100644
--- a/admin/i18n/nl/translations.json
+++ b/admin/i18n/nl/translations.json
@@ -2,6 +2,6 @@
"Check license": "Controleer licentie",
"License:": "Licentiesleutel:",
"Service is offline. Please try later.": "Service is offline of geen internet beschikbaar. Probeer het later opnieuw of controleer de internetverbinding.",
- "instruction": "Als u vis wilt gebruiken, moet u hiervoor de licentiesleutel hebben.
vis is gratis voor privégebruik, maar voor commercieel gebruik heeft het een prijs.
You kan de licentie krijgen op iobroker.net na een korte registratie.",
+ "instruction": "Als u vis wilt gebruiken, moet u hiervoor de licentiesleutel hebben.
vis is gratis voor privégebruik, maar voor commercieel gebruik heeft het een prijs.
You kan de licentie krijgen op yunkong2.net na een korte registratie.",
"vis adapter settings": "vis adapter instellingen"
}
\ No newline at end of file
diff --git a/admin/i18n/pl/translations.json b/admin/i18n/pl/translations.json
index 8828332..19f9b22 100644
--- a/admin/i18n/pl/translations.json
+++ b/admin/i18n/pl/translations.json
@@ -2,6 +2,6 @@
"Check license": "Sprawdź licencję",
"License:": "Klucz licencyjny:",
"Service is offline. Please try later.": "Usługa jest niedostępna lub nie ma dostępu do Internetu. Spróbuj później lub sprawdź połączenie internetowe.",
- "instruction": "Aby użyć vis , musisz uzyskać klucz licencyjny. vis jest bezpłatny do użytku prywatnego, ale do celów komercyjnych ma swoją cenę. może uzyskać licencję na iobroker.net po krótkiej rejestracji.",
+ "instruction": "Aby użyć vis , musisz uzyskać klucz licencyjny. vis jest bezpłatny do użytku prywatnego, ale do celów komercyjnych ma swoją cenę. może uzyskać licencję na yunkong2.net po krótkiej rejestracji.",
"vis adapter settings": "ustawienia adaptera vis"
}
\ No newline at end of file
diff --git a/admin/i18n/pt/translations.json b/admin/i18n/pt/translations.json
index 6efb886..38d0cef 100644
--- a/admin/i18n/pt/translations.json
+++ b/admin/i18n/pt/translations.json
@@ -2,6 +2,6 @@
"Check license": "Verifique a licença",
"License:": "Chave de licença:",
"Service is offline. Please try later.": "O serviço está offline ou não há internet disponível. Por favor tente mais tarde ou confira a conexão com a internet.",
- "instruction": "Para usar vis , você deve obter a chave de licença para isso. vis é grátis para uso privado, mas para uso comercial, ele tem um preço.
Você pode obter a licença em iobroker.net após curto registro.",
+ "instruction": "Para usar vis , você deve obter a chave de licença para isso. vis é grátis para uso privado, mas para uso comercial, ele tem um preço.
Você pode obter a licença em yunkong2.net após curto registro.",
"vis adapter settings": "vis as configurações do adaptador"
}
\ No newline at end of file
diff --git a/admin/i18n/ru/translations.json b/admin/i18n/ru/translations.json
index acc2fc7..47d8a3a 100644
--- a/admin/i18n/ru/translations.json
+++ b/admin/i18n/ru/translations.json
@@ -2,6 +2,6 @@
"Check license": "Проверить лицензию",
"License:": "Лицензионный ключ:",
"Service is offline. Please try later.": "Сервис сейчас недоступен или нет интернет соединения. Попробуйте попозже или проверте интеренет соединение.",
- "instruction": "Для пользования vis необходимо получить лицензионный ключ.
vis бесплатен для личного использования в некоммерческих целях. Для использования vis в коммерческих целях необходимо заплатить за лицензию.
Лицензионный ключ можно получить здесь iobroker.net после регистрации.",
+ "instruction": "Для пользования vis необходимо получить лицензионный ключ.
vis бесплатен для личного использования в некоммерческих целях. Для использования vis в коммерческих целях необходимо заплатить за лицензию.
Лицензионный ключ можно получить здесь yunkong2.net после регистрации.",
"vis adapter settings": "Настройки драйвера vis"
}
\ No newline at end of file
diff --git a/admin/index.html b/admin/index.html
index 67b4647..1b9ef63 100644
--- a/admin/index.html
+++ b/admin/index.html
@@ -61,7 +61,7 @@
$.ajax({
type: 'POST',
- url: 'https://iobroker.net/cert/',
+ url: 'https://yunkong2.net/cert/',
data: $('#license').val(),
contentType: 'text/plain',
xhrFields: {
diff --git a/admin/index_m.html b/admin/index_m.html
index 7bbe089..ba0c6dd 100644
--- a/admin/index_m.html
+++ b/admin/index_m.html
@@ -76,7 +76,7 @@
$.ajax({
type: 'POST',
- url: 'https://iobroker.net/cert/',
+ url: 'https://yunkong2.net/cert/',
data: $('#license').val(),
contentType: 'text/plain',
xhrFields: {
diff --git a/admin/words.js b/admin/words.js
index 4a26d92..eb9db35 100644
--- a/admin/words.js
+++ b/admin/words.js
@@ -6,6 +6,6 @@ systemDictionary = {
"Check license": { "en": "Check license", "de": "Lizenz prüfen", "ru": "Проверить лицензию", "pt": "Verifique a licença", "nl": "Controleer licentie", "fr": "Vérifier la licence", "it": "Controlla la licenza", "es": "Verificar licencia", "pl": "Sprawdź licencję"},
"License:": { "en": "License key:", "de": "License Key:", "ru": "Лицензионный ключ:", "pt": "Chave de licença:", "nl": "Licentiesleutel:", "fr": "Clé de licence:", "it": "Chiave di licenza:", "es": "Clave de licencia:", "pl": "Klucz licencyjny:"},
"Service is offline. Please try later.": { "en": "Service is offline or no internet available. Please try later or check the internet connection.", "de": "Service ist momentan nicht erreichbar oder keine Internetverbindung vorhanden. Bitte fersuchen Sie später noch ein mal oder prüfen Sie die Internetverbindung.", "ru": "Сервис сейчас недоступен или нет интернет соединения. Попробуйте попозже или проверте интеренет соединение.", "pt": "O serviço está offline ou não há internet disponível. Por favor tente mais tarde ou confira a conexão com a internet.", "nl": "Service is offline of geen internet beschikbaar. Probeer het later opnieuw of controleer de internetverbinding.", "fr": "Le service est hors ligne ou pas disponible sur Internet. Veuillez réessayer plus tard ou vérifier la connexion Internet.", "it": "Il servizio è offline o non disponibile su Internet. Si prega di provare più tardi o controllare la connessione internet.", "es": "El servicio está fuera de línea o no hay internet disponible. Por favor intente más tarde o verifique la conexión a internet.", "pl": "Usługa jest niedostępna lub nie ma dostępu do Internetu. Spróbuj później lub sprawdź połączenie internetowe."},
- "instruction": { "en": "To use vis, you must get the license key for it.
vis is free for private use, but for commercial use it has a price.
You can get the license on iobroker.net after short registration.", "de": "Man braucht eine Lizenz um vis zu nutzen.
vis ist kostenlos für private Nutzung. Nur für kommerzielle Gebrauch muss man für eine Lizenz bezahlen.
Man kann eine Lizenz auf iobroker.net nach der Registrierung bekommen.", "ru": "Для пользования vis необходимо получить лицензионный ключ.
vis бесплатен для личного использования в некоммерческих целях. Для использования vis в коммерческих целях необходимо заплатить за лицензию.
Лицензионный ключ можно получить здесь iobroker.net после регистрации.", "pt": "Para usar vis , você deve obter a chave de licença para isso. vis é grátis para uso privado, mas para uso comercial, ele tem um preço.
Você pode obter a licença em iobroker.net após curto registro.", "nl": "Als u vis wilt gebruiken, moet u hiervoor de licentiesleutel hebben.
vis is gratis voor privégebruik, maar voor commercieel gebruik heeft het een prijs.
You kan de licentie krijgen op iobroker.net na een korte registratie.", "fr": "Pour utiliser vis , vous devez obtenir la clé de licence.
vis est libre pour un usage privé, mais pour un usage commercial, il a un prix.
Vous peut obtenir la licence sur iobroker.net après une brève inscription.", "it": "Per utilizzare vis , devi ottenere il codice di licenza per esso.
vis è gratuito per uso privato, ma per uso commerciale ha un prezzo.
Tu può ottenere la licenza su iobroker.net dopo una breve registrazione.", "es": "Para usar vis , debe obtener la clave de licencia correspondiente.
vis es gratuito para uso privado, pero para uso comercial tiene un precio.
Usted puede obtener la licencia en iobroker.net después de un breve registro.", "pl": "Aby użyć vis , musisz uzyskać klucz licencyjny. vis jest bezpłatny do użytku prywatnego, ale do celów komercyjnych ma swoją cenę. może uzyskać licencję na iobroker.net po krótkiej rejestracji."},
+ "instruction": { "en": "To use vis, you must get the license key for it.
vis is free for private use, but for commercial use it has a price.
You can get the license on yunkong2.net after short registration.", "de": "Man braucht eine Lizenz um vis zu nutzen.
vis ist kostenlos für private Nutzung. Nur für kommerzielle Gebrauch muss man für eine Lizenz bezahlen.
Man kann eine Lizenz auf yunkong2.net nach der Registrierung bekommen.", "ru": "Для пользования vis необходимо получить лицензионный ключ.
vis бесплатен для личного использования в некоммерческих целях. Для использования vis в коммерческих целях необходимо заплатить за лицензию.
Лицензионный ключ можно получить здесь yunkong2.net после регистрации.", "pt": "Para usar vis , você deve obter a chave de licença para isso. vis é grátis para uso privado, mas para uso comercial, ele tem um preço.
Você pode obter a licença em yunkong2.net após curto registro.", "nl": "Als u vis wilt gebruiken, moet u hiervoor de licentiesleutel hebben.
vis is gratis voor privégebruik, maar voor commercieel gebruik heeft het een prijs.
You kan de licentie krijgen op yunkong2.net na een korte registratie.", "fr": "Pour utiliser vis , vous devez obtenir la clé de licence.
vis est libre pour un usage privé, mais pour un usage commercial, il a un prix.
Vous peut obtenir la licence sur yunkong2.net après une brève inscription.", "it": "Per utilizzare vis , devi ottenere il codice di licenza per esso.
vis è gratuito per uso privato, ma per uso commerciale ha un prezzo.
Tu può ottenere la licenza su yunkong2.net dopo una breve registrazione.", "es": "Para usar vis , debe obtener la clave de licencia correspondiente.
vis es gratuito para uso privado, pero para uso comercial tiene un precio.
Usted puede obtener la licencia en yunkong2.net después de un breve registro.", "pl": "Aby użyć vis , musisz uzyskać klucz licencyjny. vis jest bezpłatny do użytku prywatnego, ale do celów komercyjnych ma swoją cenę. może uzyskać licencję na yunkong2.net po krótkiej rejestracji."},
"vis adapter settings": { "en": "vis adapter settings", "de": "vis Adapter-Einstellungen", "ru": "Настройки драйвера vis", "pt": "vis as configurações do adaptador", "nl": "vis adapter instellingen", "fr": "paramètres de l'adaptateur vis", "it": "impostazioni della scheda vis", "es": "vis configuración del adaptador", "pl": "ustawienia adaptera vis"},
};
\ No newline at end of file
diff --git a/appveyor.yml b/appveyor.yml
index f5eb962..8c847ce 100644
--- a/appveyor.yml
+++ b/appveyor.yml
@@ -16,8 +16,8 @@ install:
- ps: npm --version
- npm install
- npm install winston@2.3.1
- - 'npm install https://github.com/ioBroker/ioBroker.js-controller/tarball/master --production'
- - npm install iobroker.web --prefix ./node_modules/iobroker.js-controller/
+ - 'npm install https://github.com/yunkong2/yunkong2.js-controller/tarball/master --production'
+ - npm install yunkong2.web --prefix ./node_modules/yunkong2.js-controller/
test_script:
- echo %cd%
- node --version
diff --git a/io-package.json b/io-package.json
index 44caf3b..4a869eb 100644
--- a/io-package.json
+++ b/io-package.json
@@ -116,29 +116,29 @@
}
},
"desc": {
- "en": "Graphical user interface for iobroker",
- "de": "Grafische Benutzeroberfläche für iobroker",
- "ru": "Графический пользовательский интерфейс для iobroker",
- "pt": "Interface gráfica do usuário para iobroker",
- "nl": "Grafische gebruikersinterface voor iobroker",
- "fr": "Interface utilisateur graphique pour iobroker",
- "it": "Interfaccia utente grafica per iobroker",
- "es": "Interfaz gráfica de usuario para iobroker",
- "pl": "Graficzny interfejs użytkownika dla iobroker"
+ "en": "Graphical user interface for yunkong2",
+ "de": "Grafische Benutzeroberfläche für yunkong2",
+ "ru": "Графический пользовательский интерфейс для yunkong2",
+ "pt": "Interface gráfica do usuário para yunkong2",
+ "nl": "Grafische gebruikersinterface voor yunkong2",
+ "fr": "Interface utilisateur graphique pour yunkong2",
+ "it": "Interfaccia utente grafica per yunkong2",
+ "es": "Interfaz gráfica de usuario para yunkong2",
+ "pl": "Graficzny interfejs użytkownika dla yunkong2"
},
"platform": "Javascript/Node.js",
"loglevel": "info",
"icon": "vis.png",
"enabled": true,
"mode": "once",
- "extIcon": "https://raw.githubusercontent.com/iobroker/iobroker.vis/master/admin/vis.png",
+ "extIcon": "https://raw.githubusercontent.com/yunkong2/yunkong2.vis/master/admin/vis.png",
"keywords": [
"DashUI",
"GUI",
"graphical",
"scada"
],
- "readme": "https://github.com/iobroker/iobroker.vis/blob/master/README.md",
+ "readme": "https://github.com/yunkong2/yunkong2.vis/blob/master/README.md",
"authors": [
"bluefox "
],
diff --git a/lib/install.js b/lib/install.js
index d9dabab..97f1cba 100644
--- a/lib/install.js
+++ b/lib/install.js
@@ -83,7 +83,7 @@ function syncWidgetSets(onlyLocal, isLicenseError) {
var dirs = fs.readdirSync(path);
var sets = [];
for (var d = 0; d < dirs.length; d++) {
- if (dirs[d].match(/^iobroker\./i) && fs.existsSync(path + dirs[d] + '/widgets/')) {
+ if (dirs[d].match(/^yunkong2\./i) && fs.existsSync(path + dirs[d] + '/widgets/')) {
pack = null;
try {
pack = JSON.parse(fs.readFileSync(path + dirs[d] + '/io-package.json').toString());
@@ -97,7 +97,7 @@ function syncWidgetSets(onlyLocal, isLicenseError) {
try {
dirs = fs.readdirSync(__dirname + '/../../../../');
for (d = 0; d < dirs.length; d++) {
- if (dirs[d].match(/^iobroker\./i) && fs.existsSync(__dirname + '/../../../../' + dirs[d] + '/widgets/')) {
+ if (dirs[d].match(/^yunkong2\./i) && fs.existsSync(__dirname + '/../../../../' + dirs[d] + '/widgets/')) {
found = false;
name = dirs[d].toLowerCase();
for (var s = 0; s < sets.length; s++) {
@@ -139,7 +139,7 @@ function syncWidgetSets(onlyLocal, isLicenseError) {
if (!found) {
for (var b = 0; b < sets.length; b++) {
var ssName = sets[b].name.toLowerCase();
- if (ssName === 'iobroker.vis-' + name || ssName === 'iobroker.' + name) {
+ if (ssName === 'yunkong2.vis-' + name || ssName === 'yunkong2.' + name) {
found = true;
break;
}
@@ -164,7 +164,7 @@ function syncWidgetSets(onlyLocal, isLicenseError) {
} else {
for (var g = 0; g < sets.length; g++) {
var sName = sets[g].name.toLowerCase();
- if (sName === 'iobroker.vis-' + name || sName === 'iobroker.' + name) {
+ if (sName === 'yunkong2.vis-' + name || sName === 'yunkong2.' + name) {
if (sets[g].pack && sets[g].pack.native && sets[g].pack.native.always) {
widgetSets.push({name: name, always: true});
} else if (sets[g].pack && sets[g].pack.native && sets[g].pack.native.dependencies) {
diff --git a/lib/utils.js b/lib/utils.js
index c8a0eb7..6af37ff 100644
--- a/lib/utils.js
+++ b/lib/utils.js
@@ -27,8 +27,8 @@ let appName;
function getControllerDir(isInstall) {
// Find the js-controller location
const possibilities = [
- 'iobroker.js-controller',
- 'ioBroker.js-controller',
+ 'yunkong2.js-controller',
+ 'yunkong2.js-controller',
];
/** @type {string} */
let controllerPath;
diff --git a/main.js b/main.js
index e45603a..341a1c8 100644
--- a/main.js
+++ b/main.js
@@ -1,6 +1,6 @@
/**
*
- * iobroker vis Adapter
+ * yunkong2 vis Adapter
*
* (c) 2014-2017 bluefox, hobbyquaker
*
@@ -105,7 +105,7 @@ function writeFile(fileName, callback) {
function upload(callback) {
adapter.log.info('Upload ' + adapter.name + ' anew, while changes detected...');
- var file = utils.controllerDir + '/iobroker.js';
+ var file = utils.controllerDir + '/yunkong2.js';
var child = require('child_process').spawn('node', [file, 'upload', adapter.name, 'widgets']);
var count = 0;
child.stdout.on('data', function (data) {
@@ -299,14 +299,14 @@ function main() {
// first of all check license
if (!adapter.config.license || typeof adapter.config.license !== 'string') {
indicateError(function () {
- adapter.log.error('No license found for vis. Please get one on https://iobroker.net !');
+ adapter.log.error('No license found for vis. Please get one on https://yunkong2.net !');
//adapter.stop();
generatePages(true);
});
} else {
// An object of options to indicate where to post to
var postOptions = {
- host: 'iobroker.net',
+ host: 'yunkong2.net',
path: '/cert/',
method: 'POST',
headers: {
diff --git a/package.json b/package.json
index d380c43..47eeaf5 100644
--- a/package.json
+++ b/package.json
@@ -1,6 +1,6 @@
{
- "name": "iobroker.vis",
- "description": "Graphical user interface for iobroker.",
+ "name": "yunkong2.vis",
+ "description": "Graphical user interface for yunkong2.",
"version": "1.1.7",
"author": {
"name": "bluefox",
@@ -10,19 +10,19 @@
"bluefox ",
"hobbyquaker "
],
- "homepage": "https://github.com/iobroker/iobroker.vis",
+ "homepage": "https://github.com/yunkong2/yunkong2.vis",
"repository": {
"type": "git",
- "url": "https://github.com/iobroker/iobroker.vis"
+ "url": "https://github.com/yunkong2/yunkong2.vis"
},
"licenses": [
{
"type": "CC-BY-NC-4.0",
- "url": "https://github.com/iobroker/iobroker.vis/blob/master/LICENSE"
+ "url": "https://github.com/yunkong2/yunkong2.vis/blob/master/LICENSE"
}
],
"keywords": [
- "iobroker",
+ "yunkong2",
"GUI",
"DashUI",
"web interface",
@@ -35,12 +35,12 @@
"devDependencies": {
"gulp": "^3.9.1",
"gulp-replace": "^1.0.0",
- "iobroker.web": "*",
+ "yunkong2.web": "*",
"mocha": "^5.2.0",
"chai": "^4.1.2"
},
"bugs": {
- "url": "https://github.com/iobroker/iobroker.vis/issues"
+ "url": "https://github.com/yunkong2/yunkong2.vis/issues"
},
"main": "main.js",
"scripts": {
diff --git a/test/lib/setup.js b/test/lib/setup.js
index 16857ed..09cc5f3 100644
--- a/test/lib/setup.js
+++ b/test/lib/setup.js
@@ -415,7 +415,7 @@ function clearControllerLog() {
}
function clearDB() {
- var dirPath = rootDir + 'tmp/iobroker-data/sqlite';
+ var dirPath = rootDir + 'tmp/yunkong2-data/sqlite';
var files;
try {
if (fs.existsSync(dirPath)) {
diff --git a/test/testPackageFiles.js b/test/testPackageFiles.js
index c600a60..d0759c0 100644
--- a/test/testPackageFiles.js
+++ b/test/testPackageFiles.js
@@ -52,12 +52,12 @@ describe('Test package.json and io-package.json', function() {
console.log();
}
if (
- ioPackage.common.title.indexOf('iobroker') !== -1 ||
- ioPackage.common.title.indexOf('ioBroker') !== -1 ||
+ ioPackage.common.title.indexOf('yunkong2') !== -1 ||
+ ioPackage.common.title.indexOf('yunkong2') !== -1 ||
ioPackage.common.title.indexOf('adapter') !== -1 ||
ioPackage.common.title.indexOf('Adapter') !== -1
) {
- console.log('WARNING: title contains Adapter or ioBroker. It is clear anyway, that it is adapter for ioBroker.');
+ console.log('WARNING: title contains Adapter or yunkong2. It is clear anyway, that it is adapter for yunkong2.');
console.log();
}
diff --git a/www/js/vis.js b/www/js/vis.js
index 554fd05..4b17644 100644
--- a/www/js/vis.js
+++ b/www/js/vis.js
@@ -1,6 +1,6 @@
/**
- * ioBroker.vis
- * https://github.com/ioBroker/ioBroker.vis
+ * yunkong2.vis
+ * https://github.com/yunkong2/yunkong2.vis
*
* Copyright (c) 2013-2017 bluefox https://github.com/GermanBluefox, hobbyquaker https://github.com/hobbyquaker
* Creative Common Attribution-NonCommercial (CC BY-NC)
diff --git a/www/js/visAbout.js b/www/js/visAbout.js
index 15e02c9..68e4297 100644
--- a/www/js/visAbout.js
+++ b/www/js/visAbout.js
@@ -1,9 +1,9 @@
function fillAbout() {
var html = '';
html += '';
diff --git a/www/js/visEdit.js b/www/js/visEdit.js
index 16a3e87..3986be0 100644
--- a/www/js/visEdit.js
+++ b/www/js/visEdit.js
@@ -1,6 +1,6 @@
/**
- * ioBroker.vis
- * https://github.com/ioBroker/ioBroker.vis
+ * yunkong2.vis
+ * https://github.com/yunkong2/yunkong2.vis
*
* Copyright (c) 2013-2018 bluefox https://github.com/GermanBluefox, hobbyquaker https://github.com/hobbyquaker
* Creative Common Attribution-NonCommercial (CC BY-NC)
diff --git a/www/js/visEditExt.js b/www/js/visEditExt.js
index 8baf34e..67da738 100644
--- a/www/js/visEditExt.js
+++ b/www/js/visEditExt.js
@@ -1,6 +1,6 @@
/**
- * ioBroker.vis
- * https://github.com/ioBroker/ioBroker.vis
+ * yunkong2.vis
+ * https://github.com/yunkong2/yunkong2.vis
*
* Copyright (c) 2013-2018 bluefox https://github.com/GermanBluefox, hobbyquaker https://github.com/hobbyquaker
* Creative Common Attribution-NonCommercial (CC BY-NC)
@@ -13,7 +13,7 @@
* (Free for non-commercial use).
*/
-// visEdit - the ioBroker.vis Editor extensions
+// visEdit - the yunkong2.vis Editor extensions
/* jshint browser:true */
/* global _ */
diff --git a/www/js/visEditInspect.js b/www/js/visEditInspect.js
index 4d0ed9d..1f836ae 100644
--- a/www/js/visEditInspect.js
+++ b/www/js/visEditInspect.js
@@ -1,6 +1,6 @@
/**
- * ioBroker.vis
- * https://github.com/ioBroker/ioBroker.vis
+ * yunkong2.vis
+ * https://github.com/yunkong2/yunkong2.vis
*
* Copyright (c) 2013-2018 bluefox https://github.com/GermanBluefox, hobbyquaker https://github.com/hobbyquaker
* Creative Common Attribution-NonCommercial (CC BY-NC)
@@ -13,7 +13,7 @@
* (Free for non-commercial use).
*/
-// visEdit - the ioBroker.vis Editor
+// visEdit - the yunkong2.vis Editor
/* jshint browser:true */
/* global document */
/* global console */
diff --git a/www/js/visEditTemplates.js b/www/js/visEditTemplates.js
index 19fc4b2..bfebac1 100644
--- a/www/js/visEditTemplates.js
+++ b/www/js/visEditTemplates.js
@@ -1,6 +1,6 @@
/**
- * ioBroker.vis
- * https://github.com/ioBroker/ioBroker.vis
+ * yunkong2.vis
+ * https://github.com/yunkong2/yunkong2.vis
*
* Copyright (c) 2013-2018 bluefox https://github.com/GermanBluefox, hobbyquaker https://github.com/hobbyquaker
* Creative Common Attribution-NonCommercial (CC BY-NC)
diff --git a/www/js/visEditWelcome.js b/www/js/visEditWelcome.js
index 1172d59..f92c0a4 100644
--- a/www/js/visEditWelcome.js
+++ b/www/js/visEditWelcome.js
@@ -1,6 +1,6 @@
/**
- * ioBroker.vis
- * https://github.com/ioBroker/ioBroker.vis
+ * yunkong2.vis
+ * https://github.com/yunkong2/yunkong2.vis
*
* Copyright (c) 2013-2018 bluefox https://github.com/GermanBluefox, hobbyquaker https://github.com/hobbyquaker
* Creative Common Attribution-NonCommercial (CC BY-NC)
diff --git a/www/js/visWizard.js b/www/js/visWizard.js
index 9702beb..4108c9b 100644
--- a/www/js/visWizard.js
+++ b/www/js/visWizard.js
@@ -1,6 +1,6 @@
/**
- * ioBroker.vis
- * https://github.com/ioBroker/ioBroker.vis
+ * yunkong2.vis
+ * https://github.com/yunkong2/yunkong2.vis
*
* Copyright (c) 2013-2018 bluefox https://github.com/GermanBluefox, hobbyquaker https://github.com/hobbyquaker,
* Creative Common Attribution-NonCommercial (CC BY-NC)
@@ -12,7 +12,7 @@
* Licensees may copy, distribute, display, and perform the work and make derivative works based on it only for noncommercial purposes.
* (Free for non-commercial use).
*/
- // visEdit - the ioBroker.vis Editor Wizard
+ // visEdit - the yunkong2.vis Editor Wizard
'use strict';
diff --git a/www/js/words.js b/www/js/words.js
index fa44c5f..3c76f3a 100644
--- a/www/js/words.js
+++ b/www/js/words.js
@@ -1,6 +1,6 @@
/**
- * ioBroker.vis
- * https://github.com/ioBroker/ioBroker.vis
+ * yunkong2.vis
+ * https://github.com/yunkong2/yunkong2.vis
*
* Copyright (c) 2013-2018 bluefox https://github.com/GermanBluefox, hobbyquaker https://github.com/hobbyquaker
* Creative Common Attribution-NonCommercial (CC BY-NC)
diff --git a/www/js/conn.js b/www/js/conn.js
index 6c149dc..fc20424 100644
--- a/www/js/conn.js
+++ b/www/js/conn.js
@@ -160,9 +160,9 @@ var servConn = {
}
},
reload: function () {
- if (window.location.host === 'iobroker.net' ||
- window.location.host === 'iobroker.biz' ||
- window.location.host === 'iobroker.pro') {
+ if (window.location.host === 'yunkong2.net' ||
+ window.location.host === 'yunkong2.biz' ||
+ window.location.host === 'yunkong2.pro') {
window.location = '/';
} else {
window.location.reload();
@@ -179,7 +179,7 @@ var servConn = {
if (autoSubscribe !== undefined) this._autoSubscribe = autoSubscribe;
// To start vis as local use one of:
// - start vis from directory with name local, e.g. c:/blbla/local/ioBroker.vis/www/index.html
// - do not create "_socket/info.js" file in "www" directory
// - create "_socket/info.js" file with
// var socketUrl = "local"; var socketSession = ""; sysLang="en";
@@ -232,7 +232,7 @@ var servConn = {
}
// remove port if via cloud
- if (url.match(/iobroker\.pro|iobroker\.net/)) {
+ if (url.match(/yunkong2\.pro|yunkong2\.net/)) {
url = url.replace(/:\d+/, '');
}
@@ -273,7 +273,7 @@ var servConn = {
setTimeout(function () {
var timeOut = 6000;
// If online give more time
- if (window.location.href.indexOf('iobroker.') !== -1) {
+ if (window.location.href.indexOf('yunkong2.') !== -1) {
timeOut = 12000;
}
that.waitConnect = setTimeout(function() {
@@ -179,7 +179,7 @@ var servConn = {
if (autoSubscribe !== undefined) this._autoSubscribe = autoSubscribe;
// To start vis as local use one of:
- // - start vis from directory with name local, e.g. c:/blbla/local/ioBroker.vis/www/index.html
+ // - start vis from directory with name local, e.g. c:/blbla/local/yunkong2.vis/www/index.html
// - do not create "_socket/info.js" file in "www" directory
// - create "_socket/info.js" file with